import React from 'react';
import { ModalProps } from '../Modal';
import { TranslationMeridiem } from './types';
export declare enum DateTimeTabs {
    'TwentyFour' = "24",
    'AMPM' = "AM/PM",
    'Min' = "Min",
    'Date' = "Date"
}
export interface SaveDateAction {
    readonly label: string;
    readonly onClick: (dateTime: string) => void;
}
export interface CloseDateAction {
    readonly label: string;
    readonly onClick: () => void;
}
export interface DateTimePickerProps extends ModalProps {
    /**
     * If `true` the date time picker dialog is shown.
     */
    readonly open: boolean;
    /**
     * Current date value as ISO date format.
     */
    readonly date: string;
    /**
     * Header label of date time dialog.
     */
    readonly header: string;
    /**
     * Label for the cancel button and a
     * function that fires when user clicks cancel button.
     */
    readonly onCancelAction: CloseDateAction;
    /**
     * Label for the save button and a
     * function that fires when user clicks save button
     * @param dateTime Date string in ISO date format
     */
    readonly onSaveAction: SaveDateAction;
    /**
     * Translation as locale string, used with javascript
     * Date object toLocaleString function.
     * Default `en`
     */
    readonly lang?: string;
    /**
     * If `true` will show and set the time in AM/PM format,
     * `false` will show and set time in 24 hour format.
     */
    readonly hour12: boolean;
    /**
     * Sets which tab the dialog should start at.
     * Use DateTimeTabs enum to set.
     * Default `AMPM` or `TwentyFour`
     */
    readonly initialTab?: DateTimeTabs;
    /**
     * AM/PM translation labels
     *
     * Default `AM` and `PM`
     */
    readonly hour12MeridiemLabels?: TranslationMeridiem;
}
/**
 * DateTimePicker
 *
 * Dialog that can be used for date, time and time zone settings.
 */
export declare const DateTimePicker: React.FC<DateTimePickerProps>;
