"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TableRow = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _designparams = require("../designparams");

var _Checkbox = require("../Checkbox");

var _Table = require("./Table");

var _context = require("./context");

var _TableCells = require("./TableCells");

var _excluded = ["className", "id", "children", "selected", "disabled", "clickable", "onClicked", "menu"];

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * TableRow
 *
 * A single row in the table used to group cells.
 * Note that there is no div associated with this,
 * it is just a convenience component to pass proper
 * keys to the grid cells.
 */
var TableRowGrid = _styledComponents.default.div.withConfig({
  displayName: "TableRow__TableRowGrid",
  componentId: "sc-qeasnr-0"
})(["z-index:0;display:grid;position:relative;grid-template-rows:", ";&:nth-child(odd){background-color:", ";}&:nth-child(even){background-color:", ";}outline:none;", "{display:none;&:focus-within{display:flex;}}&:hover{box-shadow:", ";z-index:1;", "{display:flex;}}&.selected{background-color:", ";}pointer-events:", ";& ", "{", ";}cursor:", ";"], _designparams.componentSize.extraLarge, _ref => {
  var {
    theme
  } = _ref;
  return theme.color.background03();
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.color.background00();
}, _TableCells.TableCellMenu, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.shadow.tableRow;
},
/**sc-selector*/
_TableCells.TableCellMenu, _ref4 => {
  var {
    theme
  } = _ref4;
  return theme.color.backgroundPrimary();
}, _ref5 => {
  var {
    disabled
  } = _ref5;
  return disabled ? 'none' : undefined;
}, _TableCells.TableCellContent, _ref6 => {
  var {
    disabled
  } = _ref6;
  return disabled ? (0, _styledComponents.css)(["opacity:", ";pointer-events:none;"], _designparams.opacity[48]) : undefined;
}, _ref7 => {
  var {
    clickable,
    disabled
  } = _ref7;
  return clickable && !disabled ? 'pointer' : 'unset';
});

var TableRow = /*#__PURE__*/_react.default.memo(_ref8 => {
  var {
    className,
    id,
    children,
    selected = false,
    disabled = false,
    clickable = false,
    onClicked,
    menu
  } = _ref8,
      props = _objectWithoutProperties(_ref8, _excluded);

  var {
    onSelect,
    hasMenu
  } = (0, _react.useContext)(_context.TableContext);
  var onChange = (0, _react.useCallback)(e => {
    if (onSelect !== undefined) {
      onSelect(e.target.checked, id);
    }
  }, [id, onSelect]);
  var onRowClicked = (0, _react.useCallback)(e => {
    e.stopPropagation();

    if (onClicked !== undefined && clickable && !disabled) {
      onClicked(e);
    }
  }, [disabled, clickable, onClicked]);
  var gridTemplateColumnsStyle = (0, _Table.useGridTemplateColumns)();
  var tableCheckboxContent = (0, _react.useMemo)(() => {
    return onSelect !== undefined && !clickable ? /*#__PURE__*/_react.default.createElement(_TableCells.TableCellCheckbox, null, /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, {
      checked: selected,
      onChange: onChange,
      disabled: disabled
    })) : null;
  }, [onSelect, clickable, selected, onChange, disabled]);
  var tableCellContent = (0, _react.useMemo)(() => {
    return _react.default.Children.map(children, (cell, cellId) => {
      return /*#__PURE__*/_react.default.createElement(_TableCells.TableCellContent, {
        key: cellId
      }, cell);
    });
  }, [children]);
  var tableMenuContent = (0, _react.useMemo)(() => {
    return hasMenu ? /*#__PURE__*/_react.default.createElement(_TableCells.TableCellMenu, null, menu !== undefined ? menu : null) : null;
  }, [hasMenu, menu]);
  var tableRowClassName = (0, _react.useMemo)(() => [selected ? 'selected' : undefined, className].filter(Boolean).join(' '), [className, selected]);
  return /*#__PURE__*/_react.default.createElement(TableRowGrid, _extends({
    style: gridTemplateColumnsStyle,
    disabled: disabled,
    className: tableRowClassName,
    clickable: clickable,
    onClick: clickable ? onRowClicked : undefined
  }, props), tableCheckboxContent, tableCellContent, tableMenuContent);
});

exports.TableRow = TableRow;
TableRow.displayName = 'TableRowComponent';